@@ -16,10 +16,10 @@ import sys
 import time
 from functools import wraps
 if sys.version_info >= (3,):
-        unicode = str
-        ord = lambda x: x
+    unicode = str
+    ord = lambda x: x
 else:
-        unicode = unicode
+    unicode = unicode
 
 
 # Обертка для функций, которые могут не сработать из-за длительного простоя
@@ -116,7 +116,7 @@ def remove_key(cont, local=True, provider=None):
     return True
 
 
-def create_request(cont, params, local=True, provider=None):
+def create_request(cont, params, local=True, provider=None, defaults=False):
     """Создание запроса на сертификат
 
     :cont: Имя контейнера
@@ -157,7 +157,8 @@ def create_request(cont, params, local=True, provider=None):
     cont = _from_hex(cont)
     ctx = csp.Crypt(cont, csp.PROV_GOST_2001_DH, 0, provider)
     req = csp.CertRequest(ctx, )
-    set_q_defaults(params)
+    if defaults:
+        set_q_defaults(params)
     req.set_subject(Attributes(params.get('Attributes', [])).encode())
     validity = CertValidity(params.get('ValidFrom', datetime.now()),
                             params.get('ValidTo', datetime.now() + timedelta(days=365)))
@@ -355,6 +356,18 @@ def pkcs7_info(data):
     return res
 
 
+def cert_subject_id(cert):
+    """Функция получения Subject Key Id сертификата.
+
+    :cert: сертификат в base64, или в бинарнике
+    :returns: Строку из шестнадцатиричных цифр.
+
+    """
+    cert = autopem(cert)
+    cert = csp.Cert(cert)
+    return hexlify(cert.subject_id())
+
+
 def cert_info(cert):
     """Информация о сертификате
 
